pub enum AnyBuffer {
Show 26 variants
Binary(BinColumn),
Text(CharColumn),
WText(WCharColumn),
Date(Vec<Date>),
Time(Vec<Time>),
Timestamp(Vec<Timestamp>),
F64(Vec<f64>),
F32(Vec<f32>),
I8(Vec<i8>),
I16(Vec<i16>),
I32(Vec<i32>),
I64(Vec<i64>),
U8(Vec<u8>),
Bit(Vec<Bit>),
Numeric(Vec<Numeric>),
NullableDate(ColumnWithIndicator<Date>),
NullableTime(ColumnWithIndicator<Time>),
NullableTimestamp(ColumnWithIndicator<Timestamp>),
NullableF64(ColumnWithIndicator<f64>),
NullableF32(ColumnWithIndicator<f32>),
NullableI8(ColumnWithIndicator<i8>),
NullableI16(ColumnWithIndicator<i16>),
NullableI32(ColumnWithIndicator<i32>),
NullableI64(ColumnWithIndicator<i64>),
NullableU8(ColumnWithIndicator<u8>),
NullableBit(ColumnWithIndicator<Bit>),
}Use BoxColumnBuffer instead
Buffer holding a single column of either a result set or parameter
Variants
Binary(BinColumn)
Use BoxColumnBuffer instead
A buffer for holding both nullable and required binary data.
Text(CharColumn)
Use BoxColumnBuffer instead
A buffer for holding both nullable and required text data. Uses the system encoding for character data.
WText(WCharColumn)
Use BoxColumnBuffer instead
A buffer for holding both nullable and required text data. Uses UTF-16 encoding
Date(Vec<Date>)
Use BoxColumnBuffer instead
Time(Vec<Time>)
Use BoxColumnBuffer instead
Timestamp(Vec<Timestamp>)
Use BoxColumnBuffer instead
F64(Vec<f64>)
Use BoxColumnBuffer instead
F32(Vec<f32>)
Use BoxColumnBuffer instead
I8(Vec<i8>)
Use BoxColumnBuffer instead
I16(Vec<i16>)
Use BoxColumnBuffer instead
I32(Vec<i32>)
Use BoxColumnBuffer instead
I64(Vec<i64>)
Use BoxColumnBuffer instead
U8(Vec<u8>)
Use BoxColumnBuffer instead
Bit(Vec<Bit>)
Use BoxColumnBuffer instead
Numeric(Vec<Numeric>)
Use BoxColumnBuffer instead
NullableDate(ColumnWithIndicator<Date>)
Use BoxColumnBuffer instead
NullableTime(ColumnWithIndicator<Time>)
Use BoxColumnBuffer instead
NullableTimestamp(ColumnWithIndicator<Timestamp>)
Use BoxColumnBuffer instead
NullableF64(ColumnWithIndicator<f64>)
Use BoxColumnBuffer instead
NullableF32(ColumnWithIndicator<f32>)
Use BoxColumnBuffer instead
NullableI8(ColumnWithIndicator<i8>)
Use BoxColumnBuffer instead
NullableI16(ColumnWithIndicator<i16>)
Use BoxColumnBuffer instead
NullableI32(ColumnWithIndicator<i32>)
Use BoxColumnBuffer instead
NullableI64(ColumnWithIndicator<i64>)
Use BoxColumnBuffer instead
NullableU8(ColumnWithIndicator<u8>)
Use BoxColumnBuffer instead
NullableBit(ColumnWithIndicator<Bit>)
Use BoxColumnBuffer instead
Implementations
Sourceimpl AnyBuffer
impl AnyBuffer
Sourcepub fn try_from_desc(
max_rows: usize,
desc: BufferDesc,
) -> Result<Self, TooLargeBufferSize>
pub fn try_from_desc( max_rows: usize, desc: BufferDesc, ) -> Result<Self, TooLargeBufferSize>
Map buffer description to actual buffer.
Sourcepub fn from_desc(max_rows: usize, desc: BufferDesc) -> Self
pub fn from_desc(max_rows: usize, desc: BufferDesc) -> Self
Map buffer description to actual buffer.