BoxColumBufferRefMut

Struct BoxColumBufferRefMut 

pub struct BoxColumBufferRefMut<'a> { /* private fields */ }
Fat reference to a BoxColumnBuffer that is bound as an array parameter to a [Statement].

This reference allows mutating the buffer contents, e.g. in order to reuse the same bound buffer for inserting multiple batches of data. If any operation is performed which would invalidate the column buffer will be automatically re-bound to the statement.

Implementations

Source

impl<'a> BoxColumBufferRefMut<'a>

pub fn of<T>(self) -> Option<T::SliceMut>
where T: BoundInputSlice<'a> + 'static,

Fetch the associated slice if we know the underlying buffer to be of type T.

pub fn as_wide_text(self) -> Option<TextColumnSliceMut<'a, u16>>

Use this if you know the underlying buffer holds wide (i.e. UTF-16) character data and you want to access it.

Some if the the underlying buffer is of type TextColumn with u16 values. Same as Self::of::<TextColumn<u16>>.

pub fn as_text(self) -> Option<TextColumnSliceMut<'a, u8>>

Use this if you know the underlying buffer holds narrow (e.g. UTF-8) character data and you want to access it.

Some if the the underlying buffer is of type TextColumn with u8 values. Same as Self::of::<TextColumn<u8>>.

pub fn as_binary(self) -> Option<BinColumnSliceMut<'a>>

Use this if you know the underlying buffer holds binary data and you want to access it.

Some if the the underlying buffer is of type BinColumn. Same as Self::of::<BinColumn>.

pub fn as_slice<T>(self) -> Option<&'a mut [T]>
where T: Pod,

pub fn as_nullable_slice<T>(self) -> Option<NullableSliceMut<'a, T>>
where T: Pod,