pub trait Resize {
// Required method
fn resize(&mut self, new_capacity: usize);
}Expand description
A column buffer which can be resized.
Resizing is useful if a column buffer is used for inserting parameters, rather than fetching. Imagine an application which inserts data from a stream with row groups of varying size. If it encounters a row group with a new maximum size, it may want to resize the parameter buffers to send the entire row group in one go.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".