BoxColumnBuffer

Type Alias BoxColumnBuffer 

pub type BoxColumnBuffer = Box<dyn AnyColumnBuffer>;
Heap allocated column buffer with dynamic type. Intended to be used as a type parameter for ColumnarBuffer to enable columns of different types only known at runtime to be bound to the same block cursor.

Aliased Type

pub struct BoxColumnBuffer(/* private fields */);