Enum odbc_api::DriverCompleteOption [−][src]
pub enum DriverCompleteOption<'a> {
NoPrompt,
Prompt(&'a dyn HasRawWindowHandle),
Complete(&'a dyn HasRawWindowHandle),
CompleteRequired(&'a dyn HasRawWindowHandle),
}Expand description
Specifies how the driver and driver manager complete the incoming connection string. See
Environment::driver_connect.
Variants
Do not show a prompt to the user. This implies that the connection string, must already provide all information needed to Connect to the data source, otherwise the operation fails. This is the only variant on non windows platforms
Prompt(&'a dyn HasRawWindowHandle)Always show a prompt to the user.
Complete(&'a dyn HasRawWindowHandle)Only show a prompt to the user if the information in the connection string is not sufficient to connect to the data source.
CompleteRequired(&'a dyn HasRawWindowHandle)Like complete, but the user may not change any information already provided within the connection string.
Implementations