pub struct ColumnType {
pub nullability: Nullability,
pub data_type: DataType,
}Expand description
The relational type of a column or parameter, including nullability. Returned e.g. by
crate::Prepared::describe_param.
Fields
nullability: NullabilityIndicates whether the column or parameter may be NULL.
data_type: DataTypeThe SQL data type of the column or parameter.