pub struct State(pub [u8; 5]);Expand description
A buffer large enough to hold an SOLState for diagnostics
Tuple Fields
0: [u8; 5]Implementations
Sourceimpl State
impl State
Sourcepub const INVALID_STATE_TRANSACTION: State
pub const INVALID_STATE_TRANSACTION: State
Can be returned from SQLDisconnect
Sourcepub const INVALID_ATTRIBUTE_VALUE: State
pub const INVALID_ATTRIBUTE_VALUE: State
Given the specified Attribute value, an invalid value was specified in ValuePtr.
Sourcepub const INVALID_SQL_DATA_TYPE: State
pub const INVALID_SQL_DATA_TYPE: State
An invalid data type has been bound to a statement. Is also returned by SQLFetch if trying to fetch into a 64Bit Integer Buffer.
Sourcepub const STRING_DATA_RIGHT_TRUNCATION: State
pub const STRING_DATA_RIGHT_TRUNCATION: State
String or binary data returned for a column resulted in the truncation of nonblank character or non-NULL binary data. If it was a string value, it was right-truncated.
Sourcepub const INDICATOR_VARIABLE_REQUIRED_BUT_NOT_SUPPLIED: State
pub const INDICATOR_VARIABLE_REQUIRED_BUT_NOT_SUPPLIED: State
StrLen_or_IndPtr was a null pointer and NULL data was retrieved.
Sourcepub const OPTION_VALUE_CHANGED: State
pub const OPTION_VALUE_CHANGED: State
Can be returned by SQLSetStmtAttr function. We expect it in case the array set size is rejected.
Sourcepub const INVALID_ATTRIBUTE_OR_OPTION_IDENTIFIER: State
pub const INVALID_ATTRIBUTE_OR_OPTION_IDENTIFIER: State
One of two things:
- The value specified for the argument Attribute was not valid for the version of ODBC supported by the driver.
- The value specified for the argument Attribute was a read-only attribute.
Both are emitted by the driver manager, rather than the driver itself.
One example of this error code emitted is when using mdbtools. When the driver builds its
dispatch table, it comments out SQLSetStmtAttr triggering unixODBC to use the fallback
behavior implemented against SQLSetStmtOption. SQLSetStmtOption does not have any notion
of array parameters, so setting the parameter size triggers this error code.
Sourcepub fn from_chars_with_nul(code: &[SqlChar; 6]) -> Self
pub fn from_chars_with_nul(code: &[SqlChar; 6]) -> Self
Drops terminating zero and changes char type, if required