ForeignKeysRow

Struct ForeignKeysRow 

pub struct ForeignKeysRow {
Show 14 fields pub pk_catalog: VarCharArray<128>, pub pk_schema: VarCharArray<128>, pub pk_table: VarCharArray<255>, pub pk_column: VarCharArray<255>, pub fk_catalog: VarCharArray<128>, pub fk_schema: VarCharArray<128>, pub fk_table: VarCharArray<255>, pub fk_column: VarCharArray<255>, pub key_seq: i16, pub update_rule: Nullable<i16>, pub delete_rule: Nullable<i16>, pub fk_name: VarCharArray<128>, pub pk_name: VarCharArray<128>, pub deferrability: Nullable<i16>,
}
A row returned by crate::Preallocated::foreign_keys. The members are associated with the columns of the result set returned by crate::Preallocated::foreign_keys_cursor.

See: https://learn.microsoft.com/sql/odbc/reference/syntax/sqlforeignkeys-function

Fields

pk_catalog: VarCharArray<128>

Binds to the PKTABLE_CAT column. Primary key table catalog name. NULL if not applicable.

pk_schema: VarCharArray<128>

Binds to the PKTABLE_SCHEM column. Primary key table schema name. NULL if not applicable.

pk_table: VarCharArray<255>

Binds to the PKTABLE_NAME column. Primary key table name.

pk_column: VarCharArray<255>

Binds to the PKCOLUMN_NAME column. Primary key column name.

fk_catalog: VarCharArray<128>

Binds to the FKTABLE_CAT column. Foreign key table catalog name. NULL if not applicable.

fk_schema: VarCharArray<128>

Binds to the FKTABLE_SCHEM column. Foreign key table schema name. NULL if not applicable.

fk_table: VarCharArray<255>

Binds to the FKTABLE_NAME column. Foreign key table name.

fk_column: VarCharArray<255>

Binds to the FKCOLUMN_NAME column. Foreign key column name.

key_seq: i16

Binds to the KEY_SEQ column. Column sequence number in key (starting with 1).

update_rule: Nullable<i16>

Binds to the UPDATE_RULE column. Action applied to the foreign key when the SQL operation is UPDATE.

delete_rule: Nullable<i16>

Binds to the DELETE_RULE column. Action applied to the foreign key when the SQL operation is DELETE.

fk_name: VarCharArray<128>

Binds to the FK_NAME column. Foreign key name. NULL if not applicable.

pk_name: VarCharArray<128>

Binds to the PK_NAME column. Primary key name. NULL if not applicable.

deferrability: Nullable<i16>

Binds to the DEFERRABILITY column. One of: SQL_INITIALLY_DEFERRED, SQL_INITIALLY_IMMEDIATE, SQL_NOT_DEFERRABLE.