PrimaryKeysRow

Struct PrimaryKeysRow 

pub struct PrimaryKeysRow {
    pub catalog: VarCharArray<128>,
    pub schema: VarCharArray<128>,
    pub table: VarCharArray<255>,
    pub column: VarCharArray<255>,
    pub key_seq: i16,
    pub pk_name: VarCharArray<128>,
}
A row returned by the iterator returned by Preallocated::primary_keys. This members are associated with the columns of the result set returned by Preallocated::primary_keys_cursor.

See: https://learn.microsoft.com/sql/odbc/reference/syntax/sqlprimarykeys-function

Fields

catalog: VarCharArray<128>

Binds to the TABLE_CAT column. Primary key table catalog name. NULL if not applicable to the data source. If a driver supports catalogs for some tables but not for others, such as when the driver retrieves data from different DBMSs, it returns an empty string (“”) for those tables that do not have catalogs.

schema: VarCharArray<128>

Binds to TABLE_SCHEM. Primary key table schema name; NULL if not applicable to the data source. If a driver supports schemas for some tables but not for others, such as when the driver retrieves data from different DBMSs, it returns an empty string (“”) for those tables that do not have schemas.

table: VarCharArray<255>

Binds to the TABLE_NAME column. Primary key table name. Drivers must not return NULL.

column: VarCharArray<255>

Binds to the COLUMN_NAME column. Primary key column name. The driver returns an empty string for a column that does not have a name. Drivers must not return NULL.

key_seq: i16

Binds to the KEY_SEQ column. Column sequence number in key (starting with 1).

pk_name: VarCharArray<128>

Binds to the PK_NAME column. Primary key name. NULL if not applicable to the data source.