OwnedCursor

Type Alias OwnedCursor 

pub type OwnedCursor<P> = CursorImpl<StatementConnection<P>>;
A cursor which owns both its statement and its connection. It is generic over the type of ownership of the connection. E.g. [SharedConnection] or just plain [Connection].

Aliased Type

pub struct OwnedCursor<P> { /* private fields */ }