pub struct AnyColumnBufferSlice<'a> { /* private fields */ }Expand description
Enables reading the valid contents of a column buffer, while it is bound to a block cursor
as Box<dyn AnyColumnBuffer>.
Implementations
Sourceimpl<'a> AnyColumnBufferSlice<'a>
impl<'a> AnyColumnBufferSlice<'a>
Sourcepub fn of<T>(self) -> Option<T::Slice<'a>>where
T: Slice + 'static,
pub fn of<T>(self) -> Option<T::Slice<'a>>where
T: Slice + 'static,
Fetch the associated slice if we know the underlying buffer to be of type T.
Sourcepub fn as_text(self) -> Option<TextColumnSlice<'a, u8>>
pub fn as_text(self) -> Option<TextColumnSlice<'a, u8>>
Use this if you know the underlying buffer holds narrow (e.g. UTF-8) character data and you want to read it.
Some if the the underlying buffer is of type TextColumn with u8 values. Same as
Self::of::<TextColumn<u8>>.
Sourcepub fn as_wide_text(self) -> Option<TextColumnSlice<'a, u16>>
pub fn as_wide_text(self) -> Option<TextColumnSlice<'a, u16>>
Use this if you know the underlying buffer holds wide (i.e. UTF-16) character data and you want to read it.
Some if the the underlying buffer is of type TextColumn with u16 values. Same as
Self::of::<TextColumn<u16>>.
Sourcepub fn as_binary(self) -> Option<BinColumnSlice<'a>>
pub fn as_binary(self) -> Option<BinColumnSlice<'a>>
Use this if you know the underlying buffer holds binary data and you want to read it.
Some if the the underlying buffer is of type BinColumn. Same as
Self::of::<BinColumn>.
Sourcepub fn as_slice<T>(self) -> Option<&'a [T]>where
T: Pod,
pub fn as_slice<T>(self) -> Option<&'a [T]>where
T: Pod,
Use this if you know the underlying buffer to hold non-nullable data of type T.
Sourcepub fn as_nullable_slice<T>(self) -> Option<NullableSlice<'a, T>>where
T: Pod,
pub fn as_nullable_slice<T>(self) -> Option<NullableSlice<'a, T>>where
T: Pod,
Use this if you know the underlying buffer to hold nullable data of type T.