pub type BoxColumnBuffer = Box<dyn AnyColumnBuffer>;Expand description
Heap allocated column buffer with dynamic type. Intended to be used as a type parameter for
ColumnarBuffer to enable columns of different types only known at runtime to be bound to the
same block cursor.
Aliased Type
pub struct BoxColumnBuffer(/* private fields */);Trait Implementations
Sourceimpl<'a> BoundInputSlice<'a> for BoxColumnBuffer
impl<'a> BoundInputSlice<'a> for BoxColumnBuffer
Sourcetype SliceMut = BoxColumBufferRefMut<'a>
type SliceMut = BoxColumBufferRefMut<'a>
Intended to allow for modifying buffer contents, while leaving the bound parameter buffers
valid.
Sourceunsafe fn as_view_mut(
&'a mut self,
parameter_index: u16,
stmt: StatementRef<'a>,
) -> BoxColumBufferRefMut<'a>
unsafe fn as_view_mut( &'a mut self, parameter_index: u16, stmt: StatementRef<'a>, ) -> BoxColumBufferRefMut<'a>
Obtain a mutable view on a parameter buffer in order to change the parameter value(s)
submitted when executing the statement. Read more
Sourceimpl CData for BoxColumnBuffer
impl CData for BoxColumnBuffer
Sourcefn cdata_type(&self) -> CDataType
fn cdata_type(&self) -> CDataType
The identifier of the C data type of the value buffer. When it is retrieving data from the
data source with
fetch, the driver converts the data to this type. When it sends data to
the source, the driver converts the data from this type.Sourcefn indicator_ptr(&self) -> *const isize
fn indicator_ptr(&self) -> *const isize
Indicates the length of variable sized types. May be zero for fixed sized types. Used to
determine the size or existence of input parameters.
Sourcefn value_ptr(&self) -> *const c_void
fn value_ptr(&self) -> *const c_void
Pointer to a value corresponding to the one described by
cdata_type.Sourcefn buffer_length(&self) -> isize
fn buffer_length(&self) -> isize
Maximum length of the type in bytes (not characters). It is required to index values in
bound buffers, if more than one parameter is bound. Can be set to zero for types not bound
as parameter arrays, i.e.
CStr.Sourceimpl CDataMut for BoxColumnBuffer
impl CDataMut for BoxColumnBuffer
Sourcefn mut_indicator_ptr(&mut self) -> *mut isize
fn mut_indicator_ptr(&mut self) -> *mut isize
Indicates the length of variable sized types. May be zero for fixed sized types.
Sourcefn mut_value_ptr(&mut self) -> *mut c_void
fn mut_value_ptr(&mut self) -> *mut c_void
Pointer to a value corresponding to the one described by
cdata_type.Sourceimpl ColumnBuffer for BoxColumnBuffer
impl ColumnBuffer for BoxColumnBuffer
Sourceimpl Resize for BoxColumnBuffer
impl Resize for BoxColumnBuffer
Sourceimpl Slice for BoxColumnBuffer
impl Slice for BoxColumnBuffer
Sourcetype Slice<'a> = AnyColumnBufferSlice<'a>
type Slice<'a> = AnyColumnBufferSlice<'a>
Immutable view on the column data. Used in safe abstractions. User must not be able to
access uninitialized or invalid memory of the buffer through this interface.
Sourcefn slice(&self, valid_rows: usize) -> AnyColumnBufferSlice<'_>
fn slice(&self, valid_rows: usize) -> AnyColumnBufferSlice<'_>
Num rows may not exceed the actual amount of valid num_rows filled by the ODBC API. The
column buffer does not know how many elements were in the last row group, and therefore can
not guarantee the accessed element to be valid and in a defined state. It also can not panic
on accessing an undefined element.