pub type ColumnarDynBuffer = ColumnarBuffer<BoxColumnBuffer>;Expand description
Columnar buffer with dynamic column types decided at runtime.
Go to buffer implementation for this crate if fetching data. If you have no reason to use something else use this.
Aliased Type
pub struct ColumnarDynBuffer { /* private fields */ }Implementations
Sourceimpl ColumnarDynBuffer
impl ColumnarDynBuffer
Sourcepub fn from_descs(
capacity: usize,
descs: impl IntoIterator<Item = BufferDesc>,
) -> Self
pub fn from_descs( capacity: usize, descs: impl IntoIterator<Item = BufferDesc>, ) -> Self
Allocates a ColumnarDynBuffer fitting the buffer descriptions.
Sourcepub fn try_from_descs(
capacity: usize,
descs: impl IntoIterator<Item = BufferDesc>,
) -> Result<Self, Error>
pub fn try_from_descs( capacity: usize, descs: impl IntoIterator<Item = BufferDesc>, ) -> Result<Self, Error>
Allocates a ColumnarDynBuffer fitting the buffer descriptions. If not enough memory is
available to allocate the buffers this function fails with
Error::TooLargeColumnBufferSize. This function is slower than Self::from_descs which
would just panic if not enough memory is available for allocation.
Sourcepub fn from_descs_and_indices(
max_rows: usize,
description: impl Iterator<Item = (u16, BufferDesc)>,
) -> Self
pub fn from_descs_and_indices( max_rows: usize, description: impl Iterator<Item = (u16, BufferDesc)>, ) -> Self
Allows you to pass the buffer descriptions together with a one based column index referring the column, the buffer is supposed to bind to. This allows you also to ignore columns in a result set, by not binding them at all. There is no restriction on the order of column indices passed, but the function will panic, if the indices are not unique.