pub struct ColumnsRow {Show 18 fields
pub catalog: VarCharArray<128>,
pub schema: VarCharArray<128>,
pub table: VarCharArray<255>,
pub column_name: VarCharArray<255>,
pub data_type: i16,
pub type_name: VarCharArray<256>,
pub column_size: Nullable<i32>,
pub buffer_length: Nullable<i32>,
pub decimal_digits: Nullable<i16>,
pub num_prec_radix: Nullable<i16>,
pub nullable: i16,
pub remarks: VarCharArray<1024>,
pub column_default: VarCharArray<4000>,
pub sql_data_type: i16,
pub sql_datetime_sub: Nullable<i16>,
pub char_octet_length: Nullable<i32>,
pub ordinal_position: i32,
pub is_nullable: VarCharArray<4>,
}Expand description
A row returned by crate::Preallocated::columns. The members are associated with the
columns of the result set returned by crate::Preallocated::columns_cursor.
Sensible defaults for the buffer sizes for the variable-length columns have been chosen.
However, your driver could return larger strings or be guaranteed to return shoter ones. Your
ODBC driver may also choose to add additional columns at the end of the result set. If you
want to change the buffer sizes or fetch the additional driver specific data, use [
crate::Preallocated::columns_cursor directly and manually bind a columnar buffer to it.
See: https://learn.microsoft.com/sql/odbc/reference/syntax/sqlcolumns-function
Fields
catalog: VarCharArray<128>Binds to the TABLE_CAT column. Catalog name of the table. NULL if not applicable.
schema: VarCharArray<128>Binds to the TABLE_SCHEM column. Schema name of the table. NULL if not applicable.
table: VarCharArray<255>Binds to the TABLE_NAME column. Table name.
column_name: VarCharArray<255>Binds to the COLUMN_NAME column. Column name. Empty string for unnamed columns.
data_type: i16Binds to the DATA_TYPE column. SQL data type.
type_name: VarCharArray<256>Binds to the TYPE_NAME column. Data source-dependent data type name.
column_size: Nullable<i32>Binds to the COLUMN_SIZE column. Size of the column in the data source. NULL if not
applicable.
buffer_length: Nullable<i32>Binds to the BUFFER_LENGTH column. Length in bytes of data transferred on fetch.
decimal_digits: Nullable<i16>Binds to the DECIMAL_DIGITS column. Decimal digits of the column. NULL if not applicable.
num_prec_radix: Nullable<i16>Binds to the NUM_PREC_RADIX column. Either 10, 2, or NULL.
nullable: i16Binds to the NULLABLE column. Whether the column accepts NULLs.
remarks: VarCharArray<1024>Binds to the REMARKS column. Description of the column. NULL if unavailable.
column_default: VarCharArray<4000>Binds to the COLUMN_DEF column. Default value of the column. NULL if unspecified.
sql_data_type: i16Binds to the SQL_DATA_TYPE column. SQL data type as it appears in the SQL_DESC_TYPE
record field in the IRD.
sql_datetime_sub: Nullable<i16>Binds to the SQL_DATETIME_SUB column. Subtype code for datetime and interval data types.
NULL for other data types.
char_octet_length: Nullable<i32>Binds to the CHAR_OCTET_LENGTH column. Maximum length in bytes of a character or binary
column. NULL for other data types.
ordinal_position: i32Binds to the ORDINAL_POSITION column. Ordinal position of the column in the table
(starting with 1).
is_nullable: VarCharArray<4>Binds to the IS_NULLABLE column. "NO" if the column is known to be not nullable.
"YES" if the column might be nullable. Empty string if nullability is unknown.