pub unsafe trait Pod:
Default
+ Copy
+ CElement
+ CDataMut
+ Send
+ 'static {
const C_DATA_TYPE: CDataType;
}Expand description
A plain old data type. With an associated C Type. Must be completely stack allocated without any external references. In addition to that the buffer size must be known to ODBC in advance.
Safety
A type implementing this trait, must be a fixed sized type. The information in the C_DATA_TYPE
constant must be enough to determine both the size and the buffer length of an Instance.
Required Associated Constants
Sourceconst C_DATA_TYPE: CDataType
const C_DATA_TYPE: CDataType
ODBC C Data type used to bind instances to a statement.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.